import axios from 'axios';

const tempUUID = 'd4458234-75f0-410f-9fe0-b4a3a1e74266';

export default class {
  constructor(log, config, api) {
    // Check args
    if (!log || !config || !api) {
      return;
    }

    // Check config
    if (!config.name || !config.account_token || !config.device_token) {
      log.warn('Please enter all config fields.');
      return;
    }

    // All good
    this.hap = api.hap;
    this.log = log;
    this.name = config.name;
    this.device_token = config.device_token;
    this.account_token = config.account_token;
    this.juicenet = axios.create({
      baseURL: 'https://jbv1-api.emotorwerks.com',
      timeout: 5000,
      headers: {
        'Content-Type': 'application/json',
      },
    });

    this.informationService = new this.hap.Service.AccessoryInformation();
    this.informationService
      .setCharacteristic(this.hap.Characteristic.Manufacturer, 'eMotorWerks')
      .setCharacteristic(this.hap.Characteristic.Model, 'JuiceBox')
      .setCharacteristic(this.hap.Characteristic.SerialNumber, '123-456-789');

    this.batteryService = new this.hap.Service.Battery(this.name);

    this.batteryService
      .getCharacteristic(this.hap.Characteristic.ChargingState)
      .setProps({
        maxValue: 1,
      })
      .onGet(async () => this.getChargingState());
  }

  getServices() {
    return [this.plugService, this.batteryService];
  }

  // Battery Charging State
  async getChargingState() {
    try {
      this.log('Getting current state...');
      const response = await this.juicenet.post('/box_api_secure', {
        cmd: 'get_state',
        account_token: this.account_token,
        device_id: tempUUID,
        token: this.device_token,
      });
      this.log(response.data?.state);
      // 0 -> not charging
      // 1 -> charging
      switch (response.data?.state) {
        case 'charging':
          return 1;
        default:
          return 0;
      }
    } catch (error) {
      this.log.warn(error);
      return 0;
    }
  }
}
